package app;

import java.util.concurrent.Callable;
import javafx.application.Application;
import javafx.beans.binding.Bindings;
import javafx.beans.binding.ObjectBinding;
import javafx.scene.paint.Color;
import javafx.scene.Scene;
import javafx.scene.layout.Pane;
import javafx.scene.paint.CycleMethod;
import javafx.scene.paint.LinearGradient;
import javafx.scene.paint.Paint;
import javafx.scene.paint.Stop;
import javafx.stage.Stage;

/**
 * Es wurde verwendet:
 * https://stackoverflow.com/questions/18213999/how-to-create-custom-binding-types-in-javafx
 * @author Boris
 */
public class FXFirstWindow02 extends Application {
    
        private class GradientCreator implements Callable<Paint> {
            private final Stop [] stops;
            private final Scene sc;
            
            public GradientCreator (Scene s) {
                sc = s;
                stops = new Stop[] { new Stop(0, Color.BLUE),
                                     new Stop(1, Color.AQUAMARINE)};
            }
            @Override
            public Paint call() throws Exception {
                return new LinearGradient(0, 0,
                                          sc.getWidth(),
                                          sc.getHeight(),
                                          false,
                                          CycleMethod.NO_CYCLE,
                                          stops);
            }
        }
        private ObjectBinding<Paint> createBinding(
            final Scene sc
        ) {
        return Bindings.createObjectBinding(
                new GradientCreator(sc),
            /*
            new Callable<Paint>() {
                @Override
                public Paint call() throws Exception {
                    Stop [] stops;
                    LinearGradient gradient;
                      
                    stops = new Stop[] { new Stop(0, Color.GREEN), new Stop(1, Color.RED)};
                    gradient = new LinearGradient(0, 0,
                                                  sc.getWidth(),
                                                  sc.getHeight(),
                                                  false, CycleMethod.NO_CYCLE,
                                                  stops);
                    return gradient;
                }
            }, */
            sc.heightProperty(),
            sc.widthProperty()
        ) ;
    };
        
    @Override
    public void start(Stage primaryStage) {
        Pane root = new Pane();
        Scene scene = new Scene(root, 250, 200); /*
        ObjectBinding<Paint> gradientCreationBinding = createBinding(scene);
        scene.fillProperty().bind(gradientCreationBinding); */
        scene.fillProperty().bind(Bindings.createObjectBinding(new GradientCreator(scene),
                                                               scene.heightProperty(),
                                                               scene.widthProperty()));
        primaryStage.setTitle("Resize Gradient");
        primaryStage.setScene(scene);
        primaryStage.show();
    }
}
